@@ -23,7 +23,9 @@ def test_attribute_subsets() -> None:
         [j for i in sub_model_loggers for j in i.get_valid_attributes()]
     )
     all_sub_attrs = data_logger_attrs.union(model_logger_attrs)
-    assert all_attrs.issuperset(all_sub_attrs)
+    assert all_attrs.issuperset(
+        all_sub_attrs
+    ), f"Missing attrs: {all_sub_attrs - all_attrs}"
 
 
 def test_int_labels(set_test_config: Callable) -> None:
